@@ -1,7 +1,7 @@
-VERSION = (0, 2, 0)
-__doc__ = "Github API v2 library for Python"
+"Github API v2 library for Python"
+VERSION = (0, 3, 0)
+
 __author__ = "Ask Solem"
 __contact__ = "askh@opera.com"
 __homepage__ = "http://github.com/ask/python-github2"
 __version__ = ".".join(map(str, VERSION))
-
